@@ -5,8 +5,6 @@ from contrast.agent.assess.rules.providers.hardcoded_key import HardcodedKey
 from contrast.agent.assess.rules.providers.hardcoded_password import HardcodedPassword
 from contrast.utils.patch_utils import get_loaded_modules
 
-PROVIDER_CLASSES = [HardcodedKey, HardcodedPassword]
-
 PROVIDERS_THREAD_NAME = "ContrastProviders"
 
 
@@ -22,8 +20,11 @@ def _run_providers():
     """
     Providers are non-dataflow rules that analyze the contents of a module.
     """
-    for module in get_loaded_modules(use_for_patching=True).values():
-        for provider_cls in PROVIDER_CLASSES:
-            provider = provider_cls()
-            if provider.applies_to(module):
-                provider.analyze(module)
+    providers = [p for p in [HardcodedKey(), HardcodedPassword()] if not p.disabled]
+    if not providers:
+        return
+
+    loaded_modules = get_loaded_modules().values()
+    for provider in providers:
+        for module in loaded_modules:
+            provider.analyze(module)
