@@ -16,4 +16,7 @@ def get_otel_attributes(response: BaseResponseWrapper) -> dict:
     if response.status_code >= 500:
         attributes["error.type"] = str(response.status_code)
 
+    if response.headers and (content_type := response.headers.get("Content-Type")):
+        attributes["http.response.header.content_type"] = content_type
+
     return attributes
