@@ -2,18 +2,20 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import abc
 
+from contrast_vendor.webob.multidict import MultiDict
+
 
 class BaseResponseWrapper(metaclass=abc.ABCMeta):
     @property
     @abc.abstractmethod
-    def body(self):
+    def body(self) -> bytes:
         """
         Response body as bytes
         """
 
     @property
     @abc.abstractmethod
-    def headers(self):
+    def headers(self) -> MultiDict:
         """
         Response headers as a dictionary-like object.
 
@@ -31,7 +33,7 @@ class BaseResponseWrapper(metaclass=abc.ABCMeta):
 
     @property
     @abc.abstractmethod
-    def status_code(self):
+    def status_code(self) -> int:
         """
         Status code as an integer
         """
