@@ -6,5 +6,5 @@ from contrast.agent.protect.rule.base_rule import BaseRule
 class BotBlocker(BaseRule):
     RULE_NAME = "bot-blocker"
 
-    def is_prefilter(self):
+    def is_prefilter(self) -> bool:
         return self.enabled
