@@ -11,12 +11,12 @@ class CustomSearcher:
     IMPACT_HIGH = 3
     IMPACT_CRITICAL = 4
 
-    def __init__(self, searcher_id):
+    def __init__(self, searcher_id: str):
         self._searcher_id = searcher_id
 
     @property
-    def searcher_id(self):
+    def searcher_id(self) -> str:
         return self._searcher_id
 
-    def impact_of(self, value):
-        return NotImplementedError
+    def impact_of(self, value: str) -> int:
+        raise NotImplementedError
