@@ -30,7 +30,7 @@ class PickleSearcher(CustomSearcher):
     def __init__(self):
         CustomSearcher.__init__(self, self.ID)
 
-    def impact_of(self, value):
+    def impact_of(self, value: str) -> int:
         impact = self.IMPACT_NONE
 
         split_char = (
