@@ -2,9 +2,6 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import json
 
-from contrast.agent.protect.rule.nosql_injection.mongo_nosql_scanner import (
-    MongoNoSqlScanner,
-)
 from contrast.agent.protect.rule.sqli_rule import SqlInjection
 from contrast.utils.decorators import fail_quietly
 
@@ -16,17 +13,16 @@ class NoSqlInjection(SqlInjection):
 
     RULE_NAME = "nosql-injection"
 
-    def get_database_scanner(self, database):
-        return MongoNoSqlScanner()
-
-    def skip_protect_analysis(self, user_input, args, kwargs):
+    def skip_protect_analysis(
+        self, user_input: object, args: tuple, kwargs: dict[str, object]
+    ) -> bool:
         """
         nosql-injection has many potential user input types so
         let's not skip analysis
         """
         return False
 
-    def convert_input(self, user_input):
+    def convert_input(self, user_input: object) -> str:
         if not isinstance(user_input, (str, bytes)):
             user_input = obj_to_str(user_input)
 
