@@ -1,12 +1,21 @@
 # Copyright © 2025 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+from typing import TYPE_CHECKING, Callable
 import contrast
 from contrast.agent import scope
 from contrast.agent.settings import Settings
 
+if TYPE_CHECKING:
+    from contrast.agent.policy.patch_location_policy import PatchLocationPolicy
 
-def apply_rule(patch_policy, orig_func, args, kwargs):
-    context = contrast.CS__CONTEXT_TRACKER.current()
+
+def apply_rule(
+    patch_policy: "PatchLocationPolicy",
+    orig_func: Callable,
+    args: tuple,
+    kwargs: dict[str, object],
+):
+    context = contrast.REQUEST_CONTEXT.get()
 
     if (
         context is not None
