@@ -26,7 +26,6 @@ from contrast_vendor import structlog
 
 from . import (
     DEFAULT_LOG_LEVEL,
-    DEFAULT_PROGNAME,
     LOGGER_NAME,
     DEFAULT_AGENT_LOGGER_PATH,
 )
@@ -38,7 +37,6 @@ CONFIG_KEY_STDOUT = "agent.logger.stdout"
 CONFIG_KEY_STDERR = "agent.logger.stderr"
 CONFIG_KEY_LOGGER_PATH = "agent.logger.path"
 CONFIG_KEY_LOGGER_LEVEL = "agent.logger.level"
-CONFIG_KEY_PROGNAME = "agent.logger.progname"
 
 
 class module(Namespace):
@@ -52,13 +50,12 @@ def setup_basic_agent_logger(level="INFO"):
     Setup a logger without any user-supplied configuration, with defaults:
         1. log to stdout
         2. log in INFO level
-        3. with default progname
 
     The logger created here is expected to be overridden with config values
     provided later on in the middleware creation cycle.
     """
     if not module.initialized:
-        init_structlog(level, DEFAULT_AGENT_LOGGER_PATH, DEFAULT_PROGNAME)
+        init_structlog(level, DEFAULT_AGENT_LOGGER_PATH)
         module.initialized = True
 
     return structlog.getLogger(LOGGER_NAME)
@@ -74,7 +71,6 @@ def configure_agent_logger(config: AgentConfig) -> None:
     path_config_option, path = _logger_path(config)
     level_config_option = config.get_option(CONFIG_KEY_LOGGER_LEVEL)
     level = config[CONFIG_KEY_LOGGER_LEVEL].upper()
-    progname = config[CONFIG_KEY_PROGNAME]
 
     cache_logger = _cache_logger(path_config_option, level_config_option)
     rotation_config = (
@@ -89,7 +85,6 @@ def configure_agent_logger(config: AgentConfig) -> None:
     init_structlog(
         level,
         path,
-        progname,
         cache_logger=cache_logger,
         rotation_config=rotation_config,
     )
@@ -180,7 +175,7 @@ def security_log_attack(attack, evaluation):
 
     ip = port = url = method_name = "-"
 
-    if (context := contrast.CS__CONTEXT_TRACKER.current()) is not None:
+    if (context := contrast.REQUEST_CONTEXT.get()) is not None:
         ip = context.request.client_addr or "-"
         port = context.request.host_port
         method_name = context.request.method
