@@ -4,6 +4,7 @@
 Implements AST rewriter for Contrast Agent
 """
 
+from datetime import datetime, timezone
 import importlib.abc
 import importlib.machinery
 import importlib.util
@@ -13,6 +14,7 @@ import copy
 import builtins
 import operator
 import os
+import time
 from types import ModuleType
 
 # Seems like it is necessary to import this prior to rewriting to avoid some weird partial import state
@@ -32,11 +34,6 @@ from contrast_vendor.wrapt.importer import _ImportHookChainedLoader
 # application of the rewriter, which means we maximize the coverage of our
 # rewriter in application and library code.
 
-# The values of these rewrite variables cannot be changed. They are consumed externally
-# by the Agent Operator, and potentially other tools, that will break if they cannot
-# set these features as expected. DO NOT CHANGE THEM!!!
-REWRITE_FOR_PYTEST: str = "CONTRAST__AGENT__PYTHON__PYTEST_REWRITE"
-
 _CONTRAST_PACKAGES = ["contrast", "contrast_vendor", "contrast_rewriter"]
 # disable `assert` in contrast modules. We don't want to do this for contrast_vendor,
 # since some vendored packages might rely on `assert` behavior.
@@ -52,6 +49,9 @@ class DeferredLogger:
         self.messages = []
 
     def debug(self, message, *args, **kwargs):
+        kwargs.setdefault(
+            "time", datetime.now(tz=timezone.utc).isoformat().replace("+00:00", "Z")
+        )
         self.messages.append(("debug", message, args, kwargs))
 
 
@@ -62,6 +62,32 @@ class rewriter_module:
     registry = set()
 
 
+LOG_TIME_FORMAT = "%Y-%m-%d %H:%M:%S"
+LOG_FORMAT = "{date_and_time} [{logger_name}] {msg}"
+
+
+def log_stderr(msg: str, *, logger_name: str):
+    """
+    A basic logger that only depends on modules loaded before `sitecustomize`. Use
+    sparingly, as these are highly visible and not configurable. We send all early logs
+    to stderr (in structlog too) to minimize the probability of interfering with non-app
+    process output in flex agent or operator environments.
+
+    Use for log messages emitted before we have access to structlog.
+    """
+    date_and_time = time.strftime(LOG_TIME_FORMAT, time.localtime())
+    output = LOG_FORMAT.format(
+        date_and_time=date_and_time,
+        logger_name=logger_name,
+        msg=msg,
+    )
+    print(output, file=sys.stderr)
+
+
+def _log(msg: str) -> None:
+    log_stderr(msg, logger_name="contrast-rewriter")
+
+
 def _load_module(source, module, filename, *, force_optimize=False):
     """
     Convenience method to compile and execute the given module source
@@ -191,6 +217,12 @@ class ContrastRewriteLoader(importlib.machinery.SourceFileLoader):
         if filename is None:
             return
 
+        rewriter_module.logger.debug(
+            "ContrastRewriteLoader started executing module",
+            filename=filename,
+            module_name=self.name,
+        )
+
         try:
             original_source_code = self.get_source(self.name)
             tree = ast.parse(original_source_code)
@@ -235,6 +267,11 @@ class ContrastRewriteLoader(importlib.machinery.SourceFileLoader):
         rewriter_module.registry.add(self.name)
 
         _load_module(tree, module, filename)
+        rewriter_module.logger.debug(
+            "ContrastRewriteLoader finished executing module",
+            filename=filename,
+            module_name=self.name,
+        )
 
 
 class PropagationRewriter(ast.NodeTransformer):
@@ -487,10 +524,6 @@ def is_rewriter_enabled() -> bool:
     return rewriter_module.enabled
 
 
-def rewrite_for_pytest() -> bool:
-    return REWRITE_FOR_PYTEST in os.environ
-
-
 def module_was_rewritten(name: str) -> bool:
     return name in rewriter_module.registry
 
